@@ -26,12 +26,12 @@ class Command(BaseCommand):
         Creates a local backup set
         """
 
-        self._create_backup(output_directory=options.get('output_directory'),
-                            path_list=options.get('additional_files'))
+        self.create_backup(output_directory=options.get('output_directory'),
+                           path_list=options.get('additional_files'))
 
     @staticmethod
-    def _create_backup(output_directory, data_file='data.json',
-                       archive_file='media.zip', path_list=None):
+    def create_backup(output_directory, data_file='data.json',
+                      archive_file='media.zip', path_list=None):
         logger = log.get_logger('caretaker')
 
         if not output_directory:
@@ -62,10 +62,10 @@ class Command(BaseCommand):
             path_list.append(settings.MEDIA_ROOT)
 
         if hasattr(settings, 'ADDITIONAL_BACKUP_PATHS') \
-                and settings.ADDITIONAL_BACKUP_PATHS \
-                and settings.ADDITIONAL_BACKUP_PATHS not in path_list:
+                and settings.CARETAKER_ADDITIONAL_BACKUP_PATHS \
+                and settings.CARETAKER_ADDITIONAL_BACKUP_PATHS not in path_list:
 
-            path_list.extend(settings.ADDITIONAL_BACKUP_PATHS)
+            path_list.extend(settings.CARETAKER_ADDITIONAL_BACKUP_PATHS)
 
         path_list_final = [Path(path).expanduser().resolve(strict=True)
                            for path in path_list]
